@@ -1,13 +1,14 @@
 import shutil
-import typing as t
+from collections.abc import Callable, Iterable
 from pathlib import Path
+from typing import Optional
+
+import typer
 
 import arguebuf as ag
-import typer
-from arguebuf.cli.translator import Translator
-from arguebuf.models.edge import EdgeStyle
 
 from . import model
+from .translator import Translator
 
 cli = typer.Typer()
 
@@ -19,8 +20,8 @@ def translate(
     target_lang: str,
     auth_key: str,
     input_glob: str,
-    output_folder: t.Optional[Path] = None,
-    output_format: ag.GraphFormat = ag.GraphFormat.ARGUEBUF,
+    output_folder: Optional[Path] = None,
+    output_format: ag.dump.Format = ag.dump.Format.ARGUEBUF,
     clean: bool = False,
     overwrite: bool = False,
     start: int = 1,
@@ -34,7 +35,7 @@ def translate(
 
     path_pairs = model.PathPair.create(input_folder, output_folder, input_glob, ".json")
     translator = Translator(auth_key, source_lang, target_lang)
-    bar: t.Iterable[model.PathPair]
+    bar: Iterable[model.PathPair]
 
     with typer.progressbar(
         path_pairs[start - 1 :],
@@ -43,41 +44,50 @@ def translate(
     ) as bar:
         for path_pair in bar:
             if overwrite or not path_pair.target.exists():
-                graph = ag.Graph.from_file(path_pair.source)
-                translator.translate(graph)
-                graph.to_file(path_pair.target, output_format)
+                graph = ag.load.file(path_pair.source)
+                translator.translate_graph(graph)
+                ag.dump.file(
+                    graph, path_pair.target, ag.dump.Config(format=output_format)
+                )
 
 
-def _strip_node_labels(node: ag.Node) -> str:
-    label: str = ""
+def node_label_formatter(
+    strip_labels: bool, strip_labels_char: str | None
+) -> Callable[[ag.AbstractNode], str] | None:
+    _replace_char = "–" if strip_labels_char is None else strip_labels_char
 
-    for char in node.label:
-        if char.isspace():
-            label += char
-        else:
-            label += "–"
+    def _node_label(node: ag.AbstractNode) -> str:
+        return "".join(char if char.isspace() else _replace_char for char in node.label)
 
-    return label
+    if strip_labels:
+        return _node_label
+
+    return None
 
 
 @cli.command()
 def render(
     input_folder: Path,
     input_glob: str,
-    output_folder: t.Optional[Path] = None,
+    output_folder: Optional[Path] = None,
     output_format: str = ".pdf",
     strip_scheme_nodes: bool = False,
     strip_node_labels: bool = False,
-    edge_style: t.Optional[EdgeStyle] = None,
-    nodesep: t.Optional[float] = None,
-    ranksep: t.Optional[float] = None,
-    node_wrap_col: t.Optional[int] = None,
-    node_margin: t.Tuple[float, float] = (0, 0),
-    font_name: t.Optional[str] = None,
-    font_size: t.Optional[float] = None,
+    strip_node_labels_char: Optional[str] = None,
+    edge_style: Optional[ag.schemas.graphviz.EdgeStyle] = None,
+    nodesep: Optional[float] = None,
+    ranksep: Optional[float] = None,
+    node_wrap_col: Optional[int] = None,
+    node_margin: tuple[float, float] = (0, 0),
+    font_name: Optional[str] = None,
+    font_size: Optional[float] = None,
     clean: bool = False,
     overwrite: bool = False,
     start: int = 1,
+    max_nodes: Optional[int] = None,
+    prog: str = "dot",
+    dpi: int = 300,
+    monochrome: bool = False,
 ) -> None:
     if not output_folder:
         output_folder = input_folder
@@ -89,7 +99,7 @@ def render(
     paths = model.PathPair.create(
         input_folder, output_folder, input_glob, output_format
     )
-    bar: t.Iterable[model.PathPair]
+    bar: Iterable[model.PathPair]
 
     with typer.progressbar(
         paths[start - 1 :],
@@ -98,57 +108,57 @@ def render(
     ) as bar:
         for path_pair in bar:
             if overwrite or not path_pair.target.exists():
-                g = ag.Graph.from_file(path_pair.source)
+                g = ag.load.file(path_pair.source)
 
                 if strip_scheme_nodes:
                     g.strip_scheme_nodes()
 
-                gv = g.to_gv(
-                    format=output_format.replace(".", ""),
+                gv = ag.dump.graphviz(
+                    g,
                     nodesep=nodesep,
                     ranksep=ranksep,
                     wrap_col=node_wrap_col,
-                    margin=node_margin
-                    if all(margin > 0 for margin in node_margin)
-                    else None,
+                    margin=(
+                        node_margin
+                        if all(margin > 0 for margin in node_margin)
+                        else None
+                    ),
                     font_name=font_name,
                     font_size=font_size,
-                    atom_label=_strip_node_labels if strip_node_labels else None,
-                    scheme_label=_strip_node_labels if strip_node_labels else None,
+                    atom_label=node_label_formatter(
+                        strip_node_labels, strip_node_labels_char
+                    ),
+                    scheme_label=node_label_formatter(
+                        strip_node_labels, strip_node_labels_char
+                    ),
                     edge_style=edge_style,
+                    max_nodes=max_nodes,
+                    monochrome=monochrome,
                 )
-                ag.render(gv, path_pair.target)
+                ag.render.graphviz(gv, path_pair.target, prog, dpi)
 
 
 @cli.command()
 def convert(
     input_folder: Path,
     input_glob: str,
-    output_folder: t.Optional[Path] = None,
-    output_format: ag.GraphFormat = ag.GraphFormat.ARGUEBUF,
+    output_folder: Optional[Path] = None,
+    output_format: ag.dump.Format = ag.dump.Format.ARGUEBUF,
     clean: bool = False,
     overwrite: bool = False,
     start: int = 1,
-    text_folder: t.Optional[Path] = None,
-    text_glob: t.Optional[str] = None,
+    text_folder: Optional[Path] = None,
+    text_suffix: str = ".txt",
 ) -> None:
     if not output_folder:
         output_folder = input_folder
 
-    texts: dict[str, str] = {}
-
-    if text_folder and text_glob:
-        for file in text_folder.glob(text_glob):
-            with file.open("r") as f:
-                filename = str(file.relative_to(text_folder).with_suffix(""))
-                texts[filename] = f.read()
-
     if clean:
         shutil.rmtree(output_folder)
         output_folder.mkdir()
 
     paths = model.PathPair.create(input_folder, output_folder, input_glob, ".json")
-    bar: t.Iterable[model.PathPair]
+    bar: Iterable[model.PathPair]
 
     with typer.progressbar(
         paths[start - 1 :],
@@ -157,16 +167,19 @@ def convert(
     ) as bar:
         for path_pair in bar:
             if overwrite or not path_pair.target.exists():
-                graph = ag.Graph.from_file(path_pair.source)
-                relative_source = str(
-                    path_pair.source.relative_to(input_folder).with_suffix("")
+                text_file = None
+
+                if text_folder:
+                    text_file = text_folder / path_pair.source.relative_to(
+                        input_folder
+                    ).with_suffix(text_suffix)
+
+                graph = ag.load.file(path_pair.source, text_file=text_file)
+
+                ag.dump.file(
+                    graph, path_pair.target, ag.dump.Config(format=output_format)
                 )
 
-                if text := texts.get(relative_source):
-                    graph.add_resource(ag.Resource(text))
-
-                graph.to_file(path_pair.target, output_format)
-
 
 @cli.command()
 def statistics(
@@ -175,7 +188,7 @@ def statistics(
 ):
     files = sorted(input_folder.glob(input_glob))
 
-    graphs = [ag.Graph.from_file(file) for file in files]
+    graphs = [ag.load.file(file) for file in files]
     atom_nodes = [len(graph.atom_nodes) for graph in graphs]
     scheme_nodes = [len(graph.scheme_nodes) for graph in graphs]
     edges = [len(graph.edges) for graph in graphs]
